ChunkDatas class

Constructors

ChunkDatas({int? id, double? distance, double? duration, List<LatLng>? geometry, int? bearingAfter, int? bearingBefore, String? name, String? instruction})
ChunkDatas.fromJson(Map<String, dynamic> json, int newId)

Properties

bearingAfter ↔ int?
getter/setter pair
bearingBefore ↔ int?
getter/setter pair
distance ↔ double?
getter/setter pair
duration ↔ double?
getter/setter pair
geometry ↔ List<LatLng>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
getter/setter pair
instruction ↔ String?
getter/setter pair
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited